﻿/// <reference path="globals.js" />
/// <reference path="utils.js" />
/// <reference path="servercomm.js" />
/// <reference path="jquery-2.1.4.js" />
/// <reference path="jquery.mobile-1.4.5.js" />
/// <reference path="adNetwork.js" />
/// <reference path="user.js" />
/// <reference path="userInterfaceBindings.js" />
/// <reference path="position.js" />

var accessToken;
var TOKEN_KEY = "TKN";

// Handle logins and signups
function signUp(UserName, Password1, Password2, eMail) {
 
    // make sure passwords match
    if (Password1 != Password2) {
        trunicaAlert("Passwords do not match.");
        return;
    }

    // make sure password is valid
    if (Password1.length < 6) {
        trunicaAlert("Password is too short.  Password must be at least 6 characters long.");
        return;
    }

    // make sure email address is valid
    if (eMail != "" && validEmail(eMail) == false) {
        trunicaAlert("Please enter a valid email address.");
        return;
    }

    // make sure username is not blank and is valid (no spaces or special characters allowed)
    UserName = UserName.trim();
    if (/^[a-zA-Z0-9]*$/.test(UserName) == false) {
        trunicaAlert("User Name can only contain letters or numbers.");
        return;
    }
    if (UserName == "") {
        trunicaAlert("Please enter a User Name.");
        return;
    }

    var param = "username=" + encodeURIComponent(UserName);
    param += "&password=" + encodeURIComponent(Password1);
    param += "&email=" + encodeURIComponent(eMail);

    serverRequest("POST", "/signup", param, "Error creating account. Please try again in a few minutes.", function (xmlhttp) {
        if (/DUP/.test(xmlhttp.responseText)) {
            trunicaAlert("That user name or eMail is already in use, please choose another.");
            return;
        }
        trunicaAlert("Welcome to Shout Out!!!"); 
        completeLogin(xmlhttp);

    }, false, function(err) {
        trunicaAlert("Error creating account. Please try again in a few minutes.");
    }, false);
}

function autoLogin() {
    accessToken = localStorage.getItem(TOKEN_KEY);
    if (accessToken) {
        completeLogin(null, accessToken);
        window.location.hash = "pageHome";
    } else {
        window.location.hash = "pageLogin";
    }
    $.mobile.initializePage();
}

function login(UserName, Password) {
    if (UserName == "") { trunicaAlert("Please enter your user name to login."); return; }
    if (Password == "") { trunicaAlert("Please enter your password to login."); return; }

    // attempt login
    // send request to server
    var param = "username=" + encodeURIComponent(UserName);
    param += "&password=" + encodeURIComponent(Password);
    param += "&model=" + encodeURIComponent(device.model);
    param += "&platform=" + encodeURIComponent(device.platform);
    param += "&deviceVersion=" + encodeURIComponent(device.version);
    param += "&clientVersion=" + encodeURIComponent(APP_VERSION);
    
    serverRequest("POST", "/login", param, null,
        function (xmlhttp) {
            if (/token/.test(xmlhttp.responseText)) {
                completeLogin(xmlhttp);
            } else if (/Error/.test(xmlhttp.responseText)) {
                $("#popupBadLogin").popup("open");
            } else
                trunicaAlert("An unknown error occurred attempting login. Please try again in a few minutes.");
        },
        false, function (err) { trunicaAlert("An unknown error occurred attempting login. Please try again in a few minutes: " + err); },
        false);
}

function isLoggedIn() {
    return accessToken;
}

function logout() {
    if (AdMob) {
        AdMob.hideBanner();
    }

    stopPosition();

    localStorage.removeItem(TOKEN_KEY);
    $.mobile.changePage("#pageLogin");

    // unregister notifications
    unregisterNotifications();

    clearUserSettings();

    accessToken = null;

    resetUserInterface();
}

function completeLogin(xmlhttp, token) {
    if (xmlhttp) {
        var p =   JSON.parse(xmlhttp.responseText);
        accessToken = p.token;
    } else
        accessToken = token;
    localStorage.setItem(TOKEN_KEY, accessToken);
    getUserSettings(function () {
        //triggerMicPermission();
        if (xmlhttp)
            $.mobile.changePage("#pageHome");
        refreshCurrentTab();

        readyAdNetworks();
        
        registerNotifications(userSettings[0].UserName);
    });
}

function guestLogin() {
    accessToken = null;
    $.mobile.changePage("#pageHome");
}

function resetPassword() {
    // make sure email addresses is valid
    var e1 = $("#txtForgotEmail").val().trim();
    if (e1 != "" && validEmail(e1) == false) {
        trunicaAlert("Please enter a valid eMail address.");
        return;
    }

    var param = "email=" + encodeURIComponent(e1);
    serverRequest("POST", "/resetpassword", param, "Error sending request to reset password", function (results) {
        trunicaAlert("Instructions will be sent shortly on how to reset your password.");
        $("#popupForgot").popup("close");
        $("#txtPassword").val(null);
    }, false);
}